Index: bb-settings.php
===================================================================
--- bb-settings.php	(revision 476)
+++ bb-settings.php	(working copy)
@@ -67,7 +68,7 @@
 require( BBPATH . BBINC . '/wp-functions.php');
 if ( !( defined('WP_BB') && WP_BB ) ) {  // Don't include these when WP is running.
 	require( BBPATH . BBINC . '/kses.php');
-	if ( defined('WPLANG') && '' != constant('WPLANG') ) {
+	if ( defined('BBLANG') && '' != constant('BBLANG') ) {
 		include_once(BBPATH . BBINC . '/streams.php');
 		include_once(BBPATH . BBINC . '/gettext.php');
 	}
@@ -128,7 +129,15 @@
 
 $bb_cache = new BB_Cache();
 
-$bb_roles = new BB_Roles();
+// Load the default text localization domain.
+load_default_textdomain();
+
+// Pull in locale data after loading text domain.
+require_once(BBPATH . BBINC . '/locale.php');
+
+$bb_locale = new BB_Locale();
+$bb_roles  = new BB_Roles();
+
 do_action('bb_got_roles', '');
 
 function bb_shutdown_action_hook() {
Index: config-sample.php
===================================================================
--- config-sample.php	(revision 476)
+++ config-sample.php	(working copy)
@@ -34,6 +34,12 @@
 // Your timezone offset.  Example: -7 for Pacific Daylight Time.
 $bb->gmt_offset = 0;
 
+// Change this to localize bbPress.  A corresponding MO file for the
+// chosen language must be installed to bb-includes/languages.
+// For example, install de.mo to bb-includes/languages and set BBLANG to 'de'
+// to enable German language support.
+define('BBLANG', '');
+
 // Your Akismet Key.  You do not need a key to run bbPress, but if you want to take advantage
 // of Akismet's powerful spam blocking, you'll need one.  You can get an Akismet key at
 // http://wordpress.com/api-keys/
Index: bb-admin/admin-header.php
===================================================================
--- bb-admin/admin-header.php	(revision 476)
+++ bb-admin/admin-header.php	(working copy)
@@ -1,11 +1,12 @@
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php _e('en'); ?>">
+<html xmlns="http://www.w3.org/1999/xhtml" <?php language_attributes(); ?>>
 <head>
 	<title><?php bb_admin_title() ?></title>
 	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-	<style type="text/css">
-	 @import url(<?php option('uri'); ?>bb-admin/style.css);
-	</style>
+	<link rel="stylesheet" href="<?php option('uri'); ?>bb-admin/style.css" type="text/css" />
+<?php global $bb_locale; if ( ('rtl' == $bb_locale->text_direction) ) : ?>
+	<link rel="stylesheet" href="<?php option('uri'); ?>bb-admin/style-rtl.css" type="text/css" />
+<?php endif; ?>
 </head>
 
 <body>
Index: bb-admin/install-rtl.css
===================================================================
--- bb-admin/install-rtl.css	(revision 0)
+++ bb-admin/install-rtl.css	(revision 0)
@@ -0,0 +1 @@
+body { font-family: Tahoma, Georgia, "Times New Roman", Times, serif; }
\ No newline at end of file
Index: bb-admin/install.css
===================================================================
--- bb-admin/install.css	(revision 0)
+++ bb-admin/install.css	(revision 0)
@@ -0,0 +1,40 @@
+html { background: #eee; }
+
+body {
+	background: #fff;
+	color: #000;
+	font-family: Georgia, "Times New Roman", Times, serif;
+	margin-left: 20%;
+	margin-right: 20%;
+	padding: .2em 2em;
+}
+
+h1 {
+	color: #006;
+	font-size: 18px;
+	font-weight: lighter;
+}
+
+h2 { font-size: 16px; }
+
+p, li, dt {
+	line-height: 140%;
+	padding-bottom: 2px;
+}
+
+ul, ol { padding: 5px 5px 5px 20px; }
+
+#logo { margin-bottom: 2em; }
+
+.step a, .step input { font-size: 2em; }
+
+td input { font-size: 1.5em; }
+
+.step, th { text-align: right; }
+
+#footer {
+	text-align: center; 
+	border-top: 1px solid #ccc; 
+	padding-top: 1em; 
+	font-style: italic;
+}
\ No newline at end of file
Index: bb-admin/style-rtl.css
===================================================================
--- bb-admin/style-rtl.css	(revision 0)
+++ bb-admin/style-rtl.css	(revision 0)
@@ -0,0 +1,114 @@
+body, td { font: 13px Tahoma, "Lucida Grande", "Lucida Sans Unicode", Tahoma, Verdana; }
+
+fieldset label.selectit { padding: 0 0 0 2px; }
+
+fieldset legend { padding: .1em 0 0 .3em; }
+
+fieldset span.cat-nest {
+	margin-left: auto;
+	margin-right: 10px;
+}
+
+h2 {
+	font: normal 30px/5px serif;
+	margin: 5px 0 0 10px;
+}
+
+textarea, input, select {
+	font:  13px Verdana, Arial, Helvetica, sans-serif;
+}
+
+.alignleft {
+	float: right;
+}
+
+.alignright {
+	float: left;
+}
+
+.submit input:active, .button:active {
+	border-left-color: #ccc;
+	border-right-color: #999;
+}
+
+.submit, .editform th {
+	text-align: left;
+}
+
+.updated, .error {
+	margin: 1em 5% 10px;
+}
+
+.wrap {
+	margin: 15px 5%;
+	padding: .5em 1em;
+}
+
+.wrap h2 {
+	margin: .8em 0 .5em;
+}
+
+.widefat td, .widefat th {
+	padding: 5px 0 0 6px;
+}
+
+.widefat th {
+	text-align: right;
+}
+
+#bb-admin-menu {
+	padding: .2em 2em .3em .2em;
+	height: 30px;
+}
+
+#bb-admin-menu a {
+	margin: 0 0 0 10px;
+	display: block;
+	float: right;
+}
+
+#bb-admin-menu li { line-height: 180%; }
+
+#bb-admin-submenu {
+	padding: 3px 3em 0 2em;
+	height: 25px;
+}
+
+#bb-admin-submenu .current a {
+	border-right: 0;
+	border-left: 2px solid #049052;
+}
+
+#bb-admin-submenu a {
+	padding: .3em .4em .4em .4em;
+	margin: 0 0 0 10px;
+	display: block;
+	float: right;
+}
+
+#bb-admin-submenu li {
+	line-height: 120%;
+}
+
+#top {
+	padding: .8em 2em .8em 19em;
+}
+
+#top h1 {
+	font-family: Tahoma, Georgia, "Times New Roman", Times, serif
+}
+
+#top .login {
+	right: auto;
+	left: 1em;
+}
+
+#zeitgeist {
+	float: left;
+	margin: .5em 0 .5em 1em;
+}
+
+#zeitgeist ul {
+	margin: 0 .6em .3em 0;
+	padding: 0 .6em 0 0;
+}

Index: bb-includes/locale.php
===================================================================
--- bb-includes/locale.php	(revision 0)
+++ bb-includes/locale.php	(revision 0)
@@ -0,0 +1,149 @@
+<?php
+
+// Date and Time
+
+class BB_Locale {
+	var $weekday;
+	var $weekday_initial;
+	var $weekday_abbrev;
+
+	var $month;
+	var $month_abbrev;
+
+	var $meridiem;
+
+	var $text_direction = '';
+	var $locale_vars = array('text_direction');
+
+	function init() {
+		// The Weekdays
+		$this->weekday[0] = __('Sunday');
+		$this->weekday[1] = __('Monday');
+		$this->weekday[2] = __('Tuesday');
+		$this->weekday[3] = __('Wednesday');
+		$this->weekday[4] = __('Thursday');
+		$this->weekday[5] = __('Friday');
+		$this->weekday[6] = __('Saturday');
+
+		// The first letter of each day.  The _%day%_initial suffix is a hack to make
+		// sure the day initials are unique.
+		$this->weekday_initial[__('Sunday')]    = __('S_Sunday_initial');
+		$this->weekday_initial[__('Monday')]    = __('M_Monday_initial');
+		$this->weekday_initial[__('Tuesday')]   = __('T_Tuesday_initial');
+		$this->weekday_initial[__('Wednesday')] = __('W_Wednesday_initial');
+		$this->weekday_initial[__('Thursday')]  = __('T_Thursday_initial');
+		$this->weekday_initial[__('Friday')]    = __('F_Friday_initial');
+		$this->weekday_initial[__('Saturday')]  = __('S_Saturday_initial');
+
+		foreach ($this->weekday_initial as $weekday_ => $weekday_initial_) {
+			$this->weekday_initial[$weekday_] = preg_replace('/_.+_initial$/', '', $weekday_initial_);
+		}
+
+		// Abbreviations for each day.
+		$this->weekday_abbrev[__('Sunday')]    = __('Sun');
+		$this->weekday_abbrev[__('Monday')]    = __('Mon');
+		$this->weekday_abbrev[__('Tuesday')]   = __('Tue');
+		$this->weekday_abbrev[__('Wednesday')] = __('Wed');
+		$this->weekday_abbrev[__('Thursday')]  = __('Thu');
+		$this->weekday_abbrev[__('Friday')]    = __('Fri');
+		$this->weekday_abbrev[__('Saturday')]  = __('Sat');
+
+		// The Months
+		$this->month['01'] = __('January');
+		$this->month['02'] = __('February');
+		$this->month['03'] = __('March');
+		$this->month['04'] = __('April');
+		$this->month['05'] = __('May');
+		$this->month['06'] = __('June');
+		$this->month['07'] = __('July');
+		$this->month['08'] = __('August');
+		$this->month['09'] = __('September');
+		$this->month['10'] = __('October');
+		$this->month['11'] = __('November');
+		$this->month['12'] = __('December');
+
+		// Abbreviations for each month. Uses the same hack as above to get around the
+		// 'May' duplication.
+		$this->month_abbrev[__('January')] = __('Jan_January_abbreviation');
+		$this->month_abbrev[__('February')] = __('Feb_February_abbreviation');
+		$this->month_abbrev[__('March')] = __('Mar_March_abbreviation');
+		$this->month_abbrev[__('April')] = __('Apr_April_abbreviation');
+		$this->month_abbrev[__('May')] = __('May_May_abbreviation');
+		$this->month_abbrev[__('June')] = __('Jun_June_abbreviation');
+		$this->month_abbrev[__('July')] = __('Jul_July_abbreviation');
+		$this->month_abbrev[__('August')] = __('Aug_August_abbreviation');
+		$this->month_abbrev[__('September')] = __('Sep_September_abbreviation');
+		$this->month_abbrev[__('October')] = __('Oct_October_abbreviation');
+		$this->month_abbrev[__('November')] = __('Nov_November_abbreviation');
+		$this->month_abbrev[__('December')] = __('Dec_December_abbreviation');
+
+		foreach ($this->month_abbrev as $month_ => $month_abbrev_) {
+			$this->month_abbrev[$month_] = preg_replace('/_.+_abbreviation$/', '', $month_abbrev_);
+		}
+
+		// The Meridiems
+		$this->meridiem['am'] = __('am');
+		$this->meridiem['pm'] = __('pm');
+		$this->meridiem['AM'] = __('AM');
+		$this->meridiem['PM'] = __('PM');
+
+		$this->_load_locale_data();
+	}
+
+	function _load_locale_data() {
+		$locale = get_locale();
+		$locale_file = BBPATH . "bb-includes/languages/$locale.php";
+		if ( !file_exists($locale_file) )
+			return;
+
+		include($locale_file);
+
+		foreach ( $this->locale_vars as $var ) {
+			$this->$var = $$var;	
+		}
+	}
+
+	function get_weekday($weekday_number) {
+		return $this->weekday[$weekday_number];
+	}
+
+	function get_weekday_initial($weekday_name) {
+		return $this->weekday_initial[$weekday_name];
+	}
+
+	function get_weekday_abbrev($weekday_name) {
+		return $this->weekday_abbrev[$weekday_name];
+	}
+
+	function get_month($month_number) {
+		return $this->month[zeroise($month_number, 2)];
+	}
+
+	function get_month_initial($month_name) {
+		return $this->month_initial[$month_name];
+	}
+
+	function get_month_abbrev($month_name) {
+		return $this->month_abbrev[$month_name];
+	}
+
+	function get_meridiem($meridiem) {
+		return $this->meridiem[$meridiem];
+	}
+
+	// Global variables are deprecated. For backwards compatibility only.
+	function register_globals() {
+		$GLOBALS['weekday']         = $this->weekday;
+		$GLOBALS['weekday_initial'] = $this->weekday_initial;
+		$GLOBALS['weekday_abbrev']  = $this->weekday_abbrev;
+		$GLOBALS['month']           = $this->month;
+		$GLOBALS['month_abbrev']    = $this->month_abbrev;
+	}
+
+	function BB_Locale() {
+		$this->init();
+		$this->register_globals();
+	}
+}
+
+?>
\ No newline at end of file
Index: bb-includes/functions.php
===================================================================
--- bb-includes/functions.php	(revision 476)
+++ bb-includes/functions.php	(working copy)
@@ -305,6 +305,13 @@
 	case 'edit_lock' :
 		return $bb->edit_lock;
 		break;
+	case 'language':
+		return str_replace('_', '-', get_locale());
+		break;
+	case 'text_direction':
+		global $bb_locale;
+		return $bb_locale->text_direction;
+		break;
 	case 'version' :
 		return '0.72';
 		break; 
@@ -1433,56 +1440,25 @@
 }
 
 function bb_die($message, $title = '') {
+	global $bb_locale;
+
 	header('Content-Type: text/html; charset=utf-8');
 
 	if ( empty($title) )
 		$title = __('bbPress &rsaquo; Error');
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
+<html xmlns="http://www.w3.org/1999/xhtml" <?php language_attributes(); ?>>
 <head>
 	<title><?php echo $title ?></title>
 	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-	<style media="screen" type="text/css">
-	<!--
-	html {
-		background: #eee;
-	}
-	body {
-		background: #fff;
-		color: #000;
-		font-family: Georgia, "Times New Roman", Times, serif;
-		margin-left: 25%;
-		margin-right: 25%;
-		padding: .2em 2em;
-	}
-
-	h1 {
-		color: #060;
-		font-size: 18px;
-		font-weight: lighter;
-	}
-
-	h2 {
-		font-size: 16px;
-	}
-
-	p, li, dt {
-		line-height: 140%;
-		padding-bottom: 2px;
-	}
-
-	ul, ol {
-		padding: 5px 5px 5px 20px;
-	}
-	#logo {
-		margin-bottom: 2em;
-	}
-	-->
-	</style>
+	<link rel="stylesheet" href="<?php echo option('uri'); ?>bb-admin/install.css" type="text/css" />
+<?php if ( ('rtl' == $bb_locale->text_direction) ) : ?>
+	<link rel="stylesheet" href="<?php echo option('uri'); ?>bb-admin/install-rtl.css" type="text/css" />
+<?php endif; ?>
 </head>
 <body>
-	<h1 id="logo"><img alt="bbPress" src="<?php option('uri'); ?>bb-images/bbpress.png" /></h1>
+	<h1 id="logo"><img alt="bbPress" src="<?php echo option('uri'); ?>bb-images/bbpress.png" /></h1>
 	<p><?php echo $message; ?></p>
 </body>
 </html>
Index: bb-includes/template-functions.php
===================================================================
--- bb-includes/template-functions.php	(revision 476)
+++ bb-includes/template-functions.php	(working copy)
@@ -9,11 +9,28 @@
 	}
 }
 
-function bb_stylesheet_uri() {
+function language_attributes() {
+	$output = '';
+	if ( $dir = bb_get_option('text_direction') )
+		$output = "dir=\"$dir\"";
+	if ( $lang = bb_get_option('language') ) {
+		if ( $dir ) $output .= ' ';
+		$output .= "lang=\"$lang\" xml:lang=\"$lang\"";
+	}
+
+	echo $output;
+}
+
+function bb_stylesheet_uri($RTL = false) {
+	if ( $RTL == true )
+		$css_file = 'style-rtl.css';
+	else
+		$css_file = 'style.css';
+
 	if ( file_exists( BBPATH . 'my-templates/style.css') )
-		echo bb_get_option('uri') . 'my-templates/style.css';
+		echo bb_get_option('uri') . 'my-templates/' . $css_file;
 	else
-		echo bb_get_option('uri') . 'bb-templates/style.css';
+		echo bb_get_option('uri') . 'bb-templates/' . $css_file;
 }
 
 function bb_get_footer() {
Index: bb-includes/functions.php
===================================================================
--- bb-includes/functions.php	(revision 476)
+++ bb-includes/functions.php	(working copy)
@@ -305,6 +305,13 @@
 	case 'edit_lock' :
 		return $bb->edit_lock;
 		break;
+	case 'language':
+		return str_replace('_', '-', get_locale());
+		break;
+	case 'text_direction':
+		global $bb_locale;
+		return $bb_locale->text_direction;
+		break;
 	case 'version' :
 		return '0.72';
 		break; 
@@ -1433,56 +1440,25 @@
 }
 
 function bb_die($message, $title = '') {
+	global $bb_locale;
+
 	header('Content-Type: text/html; charset=utf-8');
 
 	if ( empty($title) )
 		$title = __('bbPress &rsaquo; Error');
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
+<html xmlns="http://www.w3.org/1999/xhtml" <?php language_attributes(); ?>>
 <head>
 	<title><?php echo $title ?></title>
 	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-	<style media="screen" type="text/css">
-	<!--
-	html {
-		background: #eee;
-	}
-	body {
-		background: #fff;
-		color: #000;
-		font-family: Georgia, "Times New Roman", Times, serif;
-		margin-left: 25%;
-		margin-right: 25%;
-		padding: .2em 2em;
-	}
-
-	h1 {
-		color: #060;
-		font-size: 18px;
-		font-weight: lighter;
-	}
-
-	h2 {
-		font-size: 16px;
-	}
-
-	p, li, dt {
-		line-height: 140%;
-		padding-bottom: 2px;
-	}
-
-	ul, ol {
-		padding: 5px 5px 5px 20px;
-	}
-	#logo {
-		margin-bottom: 2em;
-	}
-	-->
-	</style>
+	<link rel="stylesheet" href="<?php echo option('uri'); ?>bb-admin/install.css" type="text/css" />
+<?php if ( ('rtl' == $bb_locale->text_direction) ) : ?>
+	<link rel="stylesheet" href="<?php echo option('uri'); ?>bb-admin/install-rtl.css" type="text/css" />
+<?php endif; ?>
 </head>
 <body>
-	<h1 id="logo"><img alt="bbPress" src="<?php option('uri'); ?>bb-images/bbpress.png" /></h1>
+	<h1 id="logo"><img alt="bbPress" src="<?php echo option('uri'); ?>bb-images/bbpress.png" /></h1>
 	<p><?php echo $message; ?></p>
 </body>
 </html>
Index: bb-settings.php
===================================================================
--- bb-settings.php	(revision 476)
+++ bb-settings.php	(working copy)
@@ -45,6 +45,7 @@
 
 
 error_reporting(E_ALL ^ E_NOTICE);
+//error_reporting(E_ALL);
 
 define('BBINC', 'bb-includes');
 if ( !defined('BBLANGDIR') )
@@ -67,7 +68,7 @@
 require( BBPATH . BBINC . '/wp-functions.php');
 if ( !( defined('WP_BB') && WP_BB ) ) {  // Don't include these when WP is running.
 	require( BBPATH . BBINC . '/kses.php');
-	if ( defined('WPLANG') && '' != constant('WPLANG') ) {
+	if ( defined('BBLANG') && '' != constant('BBLANG') ) {
 		include_once(BBPATH . BBINC . '/streams.php');
 		include_once(BBPATH . BBINC . '/gettext.php');
 	}
@@ -128,7 +129,15 @@
 
 $bb_cache = new BB_Cache();
 
-$bb_roles = new BB_Roles();
+// Load the default text localization domain.
+load_default_textdomain();
+
+// Pull in locale data after loading text domain.
+require_once(BBPATH . BBINC . '/locale.php');
+
+$bb_locale = new BB_Locale();
+$bb_roles  = new BB_Roles();
+
 do_action('bb_got_roles', '');
 
 function bb_shutdown_action_hook() {
Index: bb-templates/front-page.php
===================================================================
--- bb-templates/front-page.php	(revision 476)
+++ bb-templates/front-page.php	(working copy)
@@ -63,7 +63,7 @@
 <h2><?php _e('Views'); ?></h2>
 <ul id="views">
 <?php foreach ( get_views() as $view => $title ) : ?>
-<li class="view"><a href="<?php echo get_view_link($view); ?>"><?php echo $view; ?></a></li>
+<li class="view"><a href="<?php echo get_view_link($view); ?>"><?php echo $title; ?></a></li>
 <?php endforeach; ?>
 </ul>
 </div>
Index: header.php
===================================================================
--- bb-templates/header.php	(revision 476)
+++ bb-templates/header.php	(working copy)
@@ -1,10 +1,13 @@
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd"> 
-<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php _e('en'); ?>">
+<html xmlns="http://www.w3.org/1999/xhtml" <?php language_attributes(); ?>>
 <head>
 	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
 	<title><?php bb_title() ?></title>
 	<?php bb_feed_head(); ?> 
 	<link rel="stylesheet" href="<?php bb_stylesheet_uri(); ?>" type="text/css" />
+<?php global $bb_locale; if ( ('rtl' == $bb_locale->text_direction) ) : ?>
+	<link rel="stylesheet" href="<?php bb_stylesheet_uri(true); ?>" type="text/css" />
+<?php endif; ?> 
 
 <?php if ( is_topic() && bb_is_user_logged_in() ) : ?>
 	<script type="text/javascript">

Index: bb-templates/style-rtl.css
===================================================================
--- bb-templates/style-rtl.css	(revision 0)
+++ bb-templates/style-rtl.css	(revision 0)
@@ -0,0 +1,76 @@
+/*
+Author: Sewar
+Author URI: http://sewar.wordpress.com
+*/
+
+body { font: 62.5% Tahoma, 'Trebuchet MS', 'Lucida Grande', Verdana, Tahoma, Arial; }
+
+code { font: 1.0em Tahoma, Monaco, 'Courier New', monospace; }
+
+fieldset table { text-align: right; }
+
+.submit, #header h1 { text-align: left; }
+
+#front-page #hottags, #topic-tags, #manage-tags li, .login label { float: right; }
+
+#front-search { float: left; }
+
+#latest th, #forumlist th, #favorites th, .num, .threadauthor small, #forumlist small { font: 11px Tahoma, Verdana, Arial, Helvetica, sans-serif; }
+
+.poststuff { font: 10px Tahoma, Verdana, Arial, Helvetica, sans-serif; }
+
+#wrapper { background: #fff url('images/page_header_tile.png') repeat-x 0px -25px; }
+
+#header { background: url('images/page_header_bblogo.png') no-repeat bottom left; }
+
+#thread { margin: 0 100px 0 0; }
+
+.user-recent ol { margin: 5px 28px 0 0; }
+
+.bbcrumb { padding: 5px 0 20px 0; }
+
+#front-page #discussions ul { padding: 0 14px 0 0; }
+
+fieldset { padding: 10px 10px 0 10px; }
+
+.login label {
+	padding-right: 0;
+	padding-left: 10px;
+}
+
+#front-page #discussions { 
+	margin-left: auto;
+	margin-right: 170px;
+}
+
+#thread li ol, #thread li ul { 
+	margin-left: 0;
+	margin-right: 40px;
+}
+
+.threadauthor {
+	margin-left: 0;
+	margin-right: -110px;
+}
+
+.infobox ul {
+	margin: 10px 12px 10px 0;
+	padding: 0;
+}
+
+#profile-menu {
+	right: auto;
+	left: 0;
+}
+
+#topic-tags {
+	border-left: 0;
+	border-right: 1px solid #ccc;
+	padding: 0 1em 1em 1em;
+}
+
+#header h1 { 
+	font-family: Tahoma, Georgia;
+	right: auto;
+	left: 59px;
+}
Index: config-sample.php
===================================================================
--- config-sample.php	(revision 476)
+++ config-sample.php	(working copy)
@@ -34,6 +34,12 @@
 // Your timezone offset.  Example: -7 for Pacific Daylight Time.
 $bb->gmt_offset = 0;
 
+// Change this to localize bbPress.  A corresponding MO file for the
+// chosen language must be installed to bb-includes/languages.
+// For example, install de.mo to bb-includes/languages and set BBLANG to 'de'
+// to enable German language support.
+define('BBLANG', '');
+
 // Your Akismet Key.  You do not need a key to run bbPress, but if you want to take advantage
 // of Akismet's powerful spam blocking, you'll need one.  You can get an Akismet key at
 // http://wordpress.com/api-keys/

Index: bb-includes/l10n.php
===================================================================
--- bb-includes/l10n.php	(revision 476)
+++ bb-includes/l10n.php	(working copy)
@@ -5,9 +5,9 @@
 	if (isset($locale))
 		return $locale;
 
-	// WPLANG is defined in wp-config.
-	if (defined('WPLANG'))
-		$locale = WPLANG;
+	// BBLANG is defined in config.php
+	if (defined('BBLANG'))
+		$locale = BBLANG;
 
 	if (empty($locale))
 		$locale = 'en_US';
@@ -69,7 +69,7 @@
 	global $l10n;
 
 	$locale = get_locale();
-	$mofile = ABSPATH . BBLANGDIR . "/$locale.mo";
+	$mofile = BBPATH . BBLANGDIR . "/$locale.mo";
 
 	load_textdomain('default', $mofile);
 }
@@ -79,7 +79,7 @@
 	if ( false === $path )
 		$path = BBPLUGINDIR;
 
-	$mofile = ABSPATH . "$path/$domain-$locale.mo";
+	$mofile = BBPATH . "$path/$domain-$locale.mo";
 	load_textdomain($domain, $mofile);
 }
 